=======
Credits
=======

Development Lead
----------------

* Eliot Berriot <contact@eliotberriot.com>

Contributors
------------

* Ryan Anguiano, via `prefs-n-perms package <https://github.com/revpoint/prefs-n-perms>`_
* [willseward](https://github.com/willseward)
* [haroon-sheikh](https://github.com/haroon-sheikh)
* [yurtaev](https://github.com/yurtaev)
* [pomerama](https://github.com/pomerama)
* [philipbelesky](https://github.com/philipbelesky)
* [what-digital](https://github.com/what-digital)
* [czlee](https://github.com/czlee)
